Current Command Extensions — django-extensions 1.6.6 documentation

# Current Command Extensions

synopsis: | Current Command Extensions

- shell_plus - An enhanced version of the Django shell. It will autoload all your models making it easy to work with the ORM right away.
- admin_generator - Generate automatic Django Admin classes by providing an app name. Outputs source code at STDOUT.
- create_app - Creates an application directory structure for the specified app name. This command allows you to specify the –template option where you can indicate a template directory structure to use as your default.
- create_command - Creates a command extension directory structure within the specified application. This makes it easy to get started with adding a command extension to your application.
- create_template_tags - Creates a template tag directory structure within the specified application.
- create_jobs - Creates a Django jobs command directory structure for the given app name in the current directory. This is part of the impressive jobs system.
- create_superuser - Makes it easy to create a superuser for the django.contrib.auth.
- clear_cache - Clear django cache, useful when testing or deploying.
- describe_form - Used to display a form definition for a model. Copy and paste the contents into your forms.py and you’re ready to go.
- dumpscript - Generates a Python script that will repopulate the database using objects. The advantage of this approach is that it is easy to understand, and more flexible than directly populating the database, or using XML.
- export_emails - export the email addresses for your users in one of many formats. Currently supports Address, Google, Outlook, LinkedIn, and VCard formats.
- generate_secret_key - Creates a new secret key that you can put in your settings.py module.
- graph_models - Creates a GraphViz dot file. You need to send this output to a file yourself. Great for graphing your models. Pass multiple application names to combine all the models into a single dot file.
- mail_debug - Starts a mail server which echos out the contents of the email instead of sending it.
- passwd - Makes it easy to reset a user’s password.
- pipchecker - Scan pip requirement file(s)s for out-of-date packages. Similar to `pip list -o` which used installed packages (in virtualenv) instead of requirements file(s).
- print_settings - Similar to `diffsettings` but shows selected active Django settings or all if no args passed.
- print_user_for_session - Print the user information for the provided session key. this is very helpful when trying to track down the person who experienced a site crash. It seems this works only if setting `SESSION_ENGINE` is `'django.contrib.sessions.backends.db'` (default value).
- drop_test_database - Drops the test database. Usefull when running Django test via some automated system (BuildBot, Jenkins, etc) and making sure that the test database is always dropped at the end.
- reset_db - Resets a database (currently sqlite3, mysql, postgres). Uses “DROP DATABASE” and “CREATE DATABASE”.
- runjob - Run a single maintenance job. Part of the jobs system.
- runjobs - Runs scheduled maintenance jobs. Specify hourly, daily, weekly, monthly. Part of the jobs system.
- runprofileserver - Starts runserver with hotshot/profiling tools enabled. I haven’t had a chance to check this one out, but it looks really cool.
- runscript - Runs a script in the django context.
- runserver_plus - The standard runserver stuff but with the Werkzeug debugger baked in. Requires Werkzeug. This one kicks ass.
- set_fake_passwords - Sets all user passwords to a common value (password by default). DEBUG only.
- show_urls - Displays the url routes that are defined in your project. Very crude at this point.
- sqldiff - Prints the (approximated) difference between an app’s models and what is in the database. This is very nice, but also very experimental at the moment. It can not catch everything but it’s a great sanity check.
- sqlcreate - Generates the SQL to create your database for you, as specified in settings.py.
- sqldsn - Reads the Django settings and extracts the parameters needed to connect to databases using other programs.
- sync_s3 - Copies files found in settings.MEDIA_ROOT to S3. Optionally can also gzip CSS and Javascript files and set the Content-Encoding header, and also set a far future expires header for browser caching.
- update_permissions - Reloads permissions for specified apps, or all apps if no args are specified.